/***************************************************************************
 *   Copyright (C) 2004 by Ingo Stierand                                   *
 *   ing.stierand@web.de                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qradiobutton.h>

#include <klocale.h>

#include "kinstallerview.h"



KInstallerView::KInstallerView(QWidget *parent)
    : KInstallerVw(parent)
{
  connect(selectButton,SIGNAL(clicked()),this,SLOT(slotSelectSourceClicked()));
  connect(installButton,SIGNAL(clicked()),this,SLOT(slotInstallClicked()));
  connect(guessButton,SIGNAL(clicked()),this,SLOT(slotGuessKDEBaseClicked()));
  connect(selectTempDirButton,SIGNAL(clicked()),this,SLOT(slotSelectTempDirClicked()));
  connect(selectPkgDirButton,SIGNAL(clicked()),this,SLOT(slotSelectPkgDirClicked()));
  
  connect(tempRadio,SIGNAL(toggled(bool)),this,SLOT(slotRadioToggled(bool)));
  connect(pkgRadio,SIGNAL(toggled(bool)),this,SLOT(slotRadioToggled(bool)));
  connect(optionsCheckBox,SIGNAL(toggled(bool)),this,SLOT(slotUseOptionsToggled(bool)));
  
  logEdit->setFocusPolicy(NoFocus);
  
  tempRadio->setChecked(true);
  slotRadioToggled(true);
  optionsCheckBox->setChecked(false);
  slotUseOptionsToggled(false);
}


KInstallerView::~KInstallerView()
{
}


QString KInstallerView::sourceURL()
{
  return(sourceEdit->text());
}


/*!
    \fn KInstallerView::setSourceURL(const QString & url)
 */
void KInstallerView::setSourceURL(const QString & url)
{
  sourceEdit->setText(url);
}


/*!
    \fn KInstallerView::KDEBase()
 */
QString KInstallerView::KDEBase()
{
  return(kdeDirEdit->text());
}


/*!
    \fn KInstallerView::setKDEBase(const QString & dir)
 */
void KInstallerView::setKDEBase(const QString & dir)
{
  kdeDirEdit->setText(dir);
}


/*!
    \fn KInstallerView::installType()
 */
KInstallerView::InstallType KInstallerView::installType()
{
  if (tempRadio->isChecked())
    return(Temporary);
  else
    return(Persistent);
}


/*!
 */
void KInstallerView::setInstallType(KInstallerView::InstallType type)
{
  if (type == Temporary)
    tempRadio->setChecked(true);
  else
    pkgRadio->setChecked(true);
}


/*!
    \fn KInstallerView::tempDir()
 */
QString KInstallerView::tempDir()
{
  return(tempDirEdit->text());
}


/*!
    \fn KInstallerView::setTempDir(const QString & dir)
 */
void KInstallerView::setTempDir(const QString & dir)
{
  tempDirEdit->setText(dir);
}


/*!
    \fn KInstallerView::pkgDir()
 */
QString KInstallerView::pkgDir()
{
  return(pkgDirEdit->text());
}


/*!
 */
void KInstallerView::setPkgDir(const QString & dir)
{
  pkgDirEdit->setText(dir);
}


/*!
 */
bool KInstallerView::useConfigureOptions()
{
  return(optionsCheckBox->isChecked());
}


/*!
 */
void KInstallerView::setUseConfigureOptions(bool use)
{
  optionsCheckBox->setChecked(use);
}


/*!
 */
QString KInstallerView::configureOptions()
{
  return(optionsEdit->text());
}


/*!
 */
void KInstallerView::setConfigureOptions(const QString & url)
{
  optionsEdit->setText(url);
}


/*!
    \fn KInstallerView::toggleInstallButton(bool running)
 */
void KInstallerView::toggleInstallButton(bool running, bool enabled)
{
  if (running)
  {
    installButton->setText(i18n("Cancel"));
    sourceFrame->setEnabled(false);
    configFrame->setEnabled(false);
  }
  else if (!enabled)
  {
    installButton->setText(i18n("Please wait ..."));
    sourceFrame->setEnabled(false);
    configFrame->setEnabled(false);
  }
  else
  {
    installButton->setText(i18n("Install now"));
    sourceFrame->setEnabled(true);
    configFrame->setEnabled(true);
  }
  
  installButton->setEnabled(enabled);
}


/*!
    \fn KInstallerView::clearLog()
 */
void KInstallerView::clearLog()
{
  logEdit->setText("");
}


/*!
    \fn KInstallerView::appendLog(const QString & text)
 */
void KInstallerView::appendLog(const QString & text)
{
  logEdit->append(text);
}


/*!
    \fn KInstallerView::slotInstallClicked()
 */
void KInstallerView::slotInstallClicked()
{
  emit signalInstallClicked();
}

/*!
    \fn KInstallerView::slotSelectSourceClicked()
 */
void KInstallerView::slotSelectSourceClicked()
{
  emit signalSelectSourceClicked();
}


/*!
    \fn KInstallerView::slotSelectTempDirClicked()
 */
void KInstallerView::slotSelectTempDirClicked()
{
  emit signalSelectTempDirClicked();
}


/*!
    \fn KInstallerView::slotSelectPkgDirClicked()
 */
void KInstallerView::slotSelectPkgDirClicked()
{
  emit signalSelectPkgpDirClicked();
}


/*!
    \fn KInstallerView::slotGuessKDEBaseClicked()
 */
void KInstallerView::slotGuessKDEBaseClicked()
{
  emit signalGuessKDEBaseClicked();
}


/*!
 */
void KInstallerView::slotRadioToggled(bool checked)
{
  bool tmp;
  
  
  if (checked)
  {
    if (tempRadio->isChecked())
    {
      tmp = true;
    }
    else
    {
      tmp = false;
    }
    
    tempDirLabel->setEnabled(tmp);
    tempDirEdit->setEnabled(tmp);
    selectTempDirButton->setEnabled(tmp);
    pkgDirLabel->setEnabled(!tmp);
    pkgDirEdit->setEnabled(!tmp);
    selectPkgDirButton->setEnabled(!tmp);
  }
}


/*!
 */
void KInstallerView::slotUseOptionsToggled(bool checked)
{
  optionsEdit->setEnabled(checked);
}

#include "kinstallerview.moc"
